{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Tumor-Only Detect Variants workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "record",
                            "name": "#vep_custom_annotation.yml/vep_custom_annotation",
                            "label": "custom annotation file to be used by vep",
                            "fields": [
                                {
                                    "type": {
                                        "type": "record",
                                        "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info",
                                        "fields": [
                                            {
                                                "type": "boolean",
                                                "label": "Identify known variants colocated with input variant",
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/check_existing"
                                            },
                                            {
                                                "type": {
                                                    "type": "enum",
                                                    "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format",
                                                    "symbols": [
                                                        "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format/bed",
                                                        "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format/gff",
                                                        "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format/gtf",
                                                        "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format/vcf",
                                                        "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format/format/bigwig"
                                                    ],
                                                    "label": "Annotation file type"
                                                },
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/data_format"
                                            },
                                            {
                                                "type": "File",
                                                "label": "File to be used for annotation, include index file",
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/file"
                                            },
                                            {
                                                "type": [
                                                    "null",
                                                    "boolean"
                                                ],
                                                "label": "Use this annotation for gnomad filtering?",
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/gnomad_filter"
                                            },
                                            {
                                                "type": "string",
                                                "label": "Used as key for new VEP annotation",
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/name"
                                            },
                                            {
                                                "type": [
                                                    "null",
                                                    {
                                                        "type": "array",
                                                        "items": "string"
                                                    }
                                                ],
                                                "label": "List of VCF fields to annotate",
                                                "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation/info/vcf_fields"
                                            }
                                        ]
                                    },
                                    "name": "#vep_custom_annotation.yml/vep_custom_annotation/annotation"
                                },
                                {
                                    "type": "boolean",
                                    "label": "Force report the overlapping coordinates of custom feature instead of based on the exact coordinates",
                                    "name": "#vep_custom_annotation.yml/vep_custom_annotation/force_report_coordinates"
                                },
                                {
                                    "type": [
                                        {
                                            "type": "enum",
                                            "symbols": [
                                                "#vep_custom_annotation.yml/vep_custom_annotation/method/exact",
                                                "#vep_custom_annotation.yml/vep_custom_annotation/method/overlap"
                                            ],
                                            "label": "Require exact or overlap to annotate variants"
                                        }
                                    ],
                                    "name": "#vep_custom_annotation.yml/vep_custom_annotation/method"
                                }
                            ]
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": true,
                    "id": "#main/annotate_coding_only"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai",
                        ".bai"
                    ],
                    "id": "#main/bam"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/docm_vcf"
                },
                {
                    "type": "File",
                    "id": "#main/interval_list"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.001,
                    "id": "#main/maximum_population_allele_frequency"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/readcount_minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/readcount_minimum_mapping_quality"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": "string",
                    "id": "#main/sample_name"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/synonyms_file"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "CHROM",
                        "POS",
                        "REF",
                        "ALT",
                        "set"
                    ],
                    "id": "#main/variants_to_table_fields"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "GT",
                        "AD",
                        "AF",
                        "DP"
                    ],
                    "id": "#main/variants_to_table_genotype_fields"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#main/varscan_min_coverage"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "id": "#main/varscan_min_reads"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "id": "#main/varscan_min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "id": "#main/varscan_p_value"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "id": "#main/varscan_strand_filter"
                },
                {
                    "type": [
                        "string",
                        "Directory"
                    ],
                    "id": "#main/vep_cache_dir"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#vep_custom_annotation.yml/vep_custom_annotation"
                    },
                    "doc": "custom type, check types directory for input format",
                    "id": "#main/vep_custom_annotations"
                },
                {
                    "type": "string",
                    "doc": "genome assembly to use in vep. Examples: GRCh38 or GRCm38",
                    "id": "#main/vep_ensembl_assembly"
                },
                {
                    "type": "string",
                    "doc": "ensembl species - Must be present in the cache directory. Examples: homo_sapiens or mus_musculus",
                    "id": "#main/vep_ensembl_species"
                },
                {
                    "type": "string",
                    "doc": "ensembl version - Must be present in the cache directory. Example: 95",
                    "id": "#main/vep_ensembl_version"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#main/vep_pick/pick",
                                "#main/vep_pick/flag_pick",
                                "#main/vep_pick/pick_allele",
                                "#main/vep_pick/per_gene",
                                "#main/vep_pick/pick_allele_gene",
                                "#main/vep_pick/flag_pick_allele",
                                "#main/vep_pick/flag_pick_allele_gene"
                            ]
                        }
                    ],
                    "id": "#main/vep_pick"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "Downstream",
                        "Wildtype"
                    ],
                    "id": "#main/vep_plugins"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "Consequence",
                        "SYMBOL",
                        "Feature_type",
                        "Feature",
                        "HGVSc",
                        "HGVSp",
                        "cDNA_position",
                        "CDS_position",
                        "Protein_position",
                        "Amino_acids",
                        "Codons",
                        "HGNC_ID",
                        "Existing_variation",
                        "gnomADe_AF",
                        "CLIN_SIG",
                        "SOMATIC",
                        "PHENO"
                    ],
                    "id": "#main/vep_to_table_fields"
                }
            ],
            "steps": [
                {
                    "run": "#vcf_readcount_annotator.cwl",
                    "in": [
                        {
                            "default": "DNA",
                            "id": "#main/add_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "source": "#main/bam_readcount/indel_bam_readcount_tsv",
                            "id": "#main/add_bam_readcount_to_vcf/indel_bam_readcount_tsv"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/add_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "source": "#main/bam_readcount/snv_bam_readcount_tsv",
                            "id": "#main/add_bam_readcount_to_vcf/snv_bam_readcount_tsv"
                        },
                        {
                            "source": "#main/annotate_variants/annotated_vcf",
                            "id": "#main/add_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#main/add_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#main/add_bam_readcount_to_vcf"
                },
                {
                    "run": "#add_vep_fields_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/variants_to_table/variants_tsv",
                            "id": "#main/add_vep_fields_to_table/tsv"
                        },
                        {
                            "source": "#main/index_filtered/indexed_vcf",
                            "id": "#main/add_vep_fields_to_table/vcf"
                        },
                        {
                            "source": "#main/vep_to_table_fields",
                            "id": "#main/add_vep_fields_to_table/vep_fields"
                        }
                    ],
                    "out": [
                        "#main/add_vep_fields_to_table/annotated_variants_tsv"
                    ],
                    "id": "#main/add_vep_fields_to_table"
                },
                {
                    "run": "#filter_vcf_custom_allele_freq.cwl",
                    "in": [
                        {
                            "source": "#main/vep_custom_annotations",
                            "valueFrom": "${\n    if(self){\n        for(var i=0; i<self.length; i++){\n            if(self[i].annotation.gnomad_filter){\n                return(self[i].annotation.name + '_AF');\n            }\n        }\n    }\n    return('gnomAD_AF');\n}\n",
                            "id": "#main/af_filter/field_name"
                        },
                        {
                            "source": "#main/maximum_population_allele_frequency",
                            "id": "#main/af_filter/maximum_population_allele_frequency"
                        },
                        {
                            "source": "#main/hard_filter/filtered_vcf",
                            "id": "#main/af_filter/vcf"
                        }
                    ],
                    "out": [
                        "#main/af_filter/filtered_vcf"
                    ],
                    "id": "#main/af_filter"
                },
                {
                    "run": "#vep.cwl",
                    "in": [
                        {
                            "source": "#main/vep_cache_dir",
                            "id": "#main/annotate_variants/cache_dir"
                        },
                        {
                            "source": "#main/annotate_coding_only",
                            "id": "#main/annotate_variants/coding_only"
                        },
                        {
                            "source": "#main/vep_custom_annotations",
                            "id": "#main/annotate_variants/custom_annotations"
                        },
                        {
                            "source": "#main/vep_ensembl_assembly",
                            "id": "#main/annotate_variants/ensembl_assembly"
                        },
                        {
                            "source": "#main/vep_ensembl_species",
                            "id": "#main/annotate_variants/ensembl_species"
                        },
                        {
                            "source": "#main/vep_ensembl_version",
                            "id": "#main/annotate_variants/ensembl_version"
                        },
                        {
                            "source": "#main/vep_pick",
                            "id": "#main/annotate_variants/pick"
                        },
                        {
                            "source": "#main/vep_plugins",
                            "id": "#main/annotate_variants/plugins"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/annotate_variants/reference"
                        },
                        {
                            "source": "#main/synonyms_file",
                            "id": "#main/annotate_variants/synonyms_file"
                        },
                        {
                            "source": "#main/decompose/decomposed_vcf",
                            "id": "#main/annotate_variants/vcf"
                        }
                    ],
                    "out": [
                        "#main/annotate_variants/annotated_vcf",
                        "#main/annotate_variants/vep_summary"
                    ],
                    "id": "#main/annotate_variants"
                },
                {
                    "run": "#bam_readcount.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/bam_readcount/bam"
                        },
                        {
                            "source": "#main/readcount_minimum_base_quality",
                            "id": "#main/bam_readcount/min_base_quality"
                        },
                        {
                            "source": "#main/readcount_minimum_mapping_quality",
                            "id": "#main/bam_readcount/min_mapping_quality"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/bam_readcount/reference_fasta"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/bam_readcount/sample"
                        },
                        {
                            "source": "#main/annotate_variants/annotated_vcf",
                            "id": "#main/bam_readcount/vcf"
                        }
                    ],
                    "out": [
                        "#main/bam_readcount/snv_bam_readcount_tsv",
                        "#main/bam_readcount/indel_bam_readcount_tsv"
                    ],
                    "id": "#main/bam_readcount"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#main/coding_variant_filter/filtered_vcf",
                            "id": "#main/bgzip_filtered/file"
                        }
                    ],
                    "out": [
                        "#main/bgzip_filtered/bgzipped_file"
                    ],
                    "id": "#main/bgzip_filtered"
                },
                {
                    "run": "#filter_vcf_coding_variant.cwl",
                    "in": [
                        {
                            "source": "#main/af_filter/filtered_vcf",
                            "id": "#main/coding_variant_filter/vcf"
                        }
                    ],
                    "out": [
                        "#main/coding_variant_filter/filtered_vcf"
                    ],
                    "id": "#main/coding_variant_filter"
                },
                {
                    "run": "#germline_combine_variants.cwl",
                    "in": [
                        {
                            "source": "#main/docm/filtered_vcf",
                            "id": "#main/combine_variants/docm_vcf"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/combine_variants/reference"
                        },
                        {
                            "source": "#main/varscan/filtered_vcf",
                            "id": "#main/combine_variants/varscan_vcf"
                        }
                    ],
                    "out": [
                        "#main/combine_variants/combined_vcf"
                    ],
                    "id": "#main/combine_variants"
                },
                {
                    "run": "#vt_decompose.cwl",
                    "in": [
                        {
                            "source": "#main/combine_variants/combined_vcf",
                            "id": "#main/decompose/vcf"
                        }
                    ],
                    "out": [
                        "#main/decompose/decomposed_vcf"
                    ],
                    "id": "#main/decompose"
                },
                {
                    "run": "#docm_germline.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/docm/bam"
                        },
                        {
                            "source": "#main/docm_vcf",
                            "id": "#main/docm/docm_vcf"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/docm/interval_list"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/docm/reference"
                        }
                    ],
                    "out": [
                        "#main/docm/unfiltered_vcf",
                        "#main/docm/filtered_vcf"
                    ],
                    "id": "#main/docm"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#main/hard_filter/exclude_filtered"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/hard_filter/interval_list"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/hard_filter/reference"
                        },
                        {
                            "source": "#main/index/indexed_vcf",
                            "id": "#main/hard_filter/vcf"
                        }
                    ],
                    "out": [
                        "#main/hard_filter/filtered_vcf"
                    ],
                    "id": "#main/hard_filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/add_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                            "id": "#main/index/vcf"
                        }
                    ],
                    "out": [
                        "#main/index/indexed_vcf"
                    ],
                    "id": "#main/index"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#main/bgzip_filtered/bgzipped_file",
                            "id": "#main/index_filtered/vcf"
                        }
                    ],
                    "out": [
                        "#main/index_filtered/indexed_vcf"
                    ],
                    "id": "#main/index_filtered"
                },
                {
                    "run": "#variants_to_table.cwl",
                    "in": [
                        {
                            "source": "#main/variants_to_table_fields",
                            "id": "#main/variants_to_table/fields"
                        },
                        {
                            "source": "#main/variants_to_table_genotype_fields",
                            "id": "#main/variants_to_table/genotype_fields"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/variants_to_table/reference"
                        },
                        {
                            "source": "#main/index_filtered/indexed_vcf",
                            "id": "#main/variants_to_table/vcf"
                        }
                    ],
                    "out": [
                        "#main/variants_to_table/variants_tsv"
                    ],
                    "id": "#main/variants_to_table"
                },
                {
                    "run": "#varscan_germline.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/varscan/bam"
                        },
                        {
                            "source": "#main/interval_list",
                            "id": "#main/varscan/interval_list"
                        },
                        {
                            "source": "#main/varscan_min_coverage",
                            "id": "#main/varscan/min_coverage"
                        },
                        {
                            "source": "#main/varscan_min_reads",
                            "id": "#main/varscan/min_reads"
                        },
                        {
                            "source": "#main/varscan_min_var_freq",
                            "id": "#main/varscan/min_var_freq"
                        },
                        {
                            "source": "#main/varscan_p_value",
                            "id": "#main/varscan/p_value"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/varscan/reference"
                        },
                        {
                            "source": "#main/sample_name",
                            "id": "#main/varscan/sample_name"
                        },
                        {
                            "source": "#main/varscan_strand_filter",
                            "id": "#main/varscan/strand_filter"
                        }
                    ],
                    "out": [
                        "#main/varscan/unfiltered_vcf",
                        "#main/varscan/filtered_vcf"
                    ],
                    "id": "#main/varscan"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/annotated_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/docm/unfiltered_vcf",
                    "id": "#main/docm_gatk_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/add_vep_fields_to_table/annotated_variants_tsv",
                    "id": "#main/final_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/index_filtered/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/final_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/bam_readcount/indel_bam_readcount_tsv",
                    "id": "#main/tumor_indel_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/bam_readcount/snv_bam_readcount_tsv",
                    "id": "#main/tumor_snv_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputSource": "#main/varscan/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/varscan_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/annotate_variants/vep_summary",
                    "id": "#main/vep_summary"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "bgzip and index VCF",
            "inputs": [
                {
                    "type": "File",
                    "id": "#bgzip_and_index.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#bgzip_and_index.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bgzip_and_index.cwl/indexed_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/vcf",
                            "id": "#bgzip_and_index.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#bgzip_and_index.cwl/bgzip"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#bgzip_and_index.cwl/bgzip/bgzipped_file",
                            "id": "#bgzip_and_index.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#bgzip_and_index.cwl/index/indexed_vcf"
                    ],
                    "id": "#bgzip_and_index.cwl/index"
                }
            ],
            "id": "#bgzip_and_index.cwl"
        },
        {
            "class": "Workflow",
            "label": "Detect DoCM variants",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#docm_germline.cwl/bam"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#docm_germline.cwl/docm_vcf"
                },
                {
                    "type": "File",
                    "id": "#docm_germline.cwl/interval_list"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#docm_germline.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#docm_germline.cwl/index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#docm_germline.cwl/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#docm_germline.cwl/gatk_haplotypecaller/docm_raw_variants",
                    "id": "#docm_germline.cwl/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#docm_germline.cwl/docm_filter/docm_filter_out",
                            "id": "#docm_germline.cwl/bgzip/file"
                        }
                    ],
                    "out": [
                        "#docm_germline.cwl/bgzip/bgzipped_file"
                    ],
                    "id": "#docm_germline.cwl/bgzip"
                },
                {
                    "run": "#single_sample_docm_filter.cwl",
                    "in": [
                        {
                            "source": "#docm_germline.cwl/gatk_haplotypecaller/docm_raw_variants",
                            "id": "#docm_germline.cwl/docm_filter/docm_out"
                        }
                    ],
                    "out": [
                        "#docm_germline.cwl/docm_filter/docm_filter_out"
                    ],
                    "id": "#docm_germline.cwl/docm_filter"
                },
                {
                    "run": "#docm_gatk_haplotype_caller.cwl",
                    "in": [
                        {
                            "source": "#docm_germline.cwl/bam",
                            "id": "#docm_germline.cwl/gatk_haplotypecaller/bam"
                        },
                        {
                            "source": "#docm_germline.cwl/docm_vcf",
                            "id": "#docm_germline.cwl/gatk_haplotypecaller/docm_vcf"
                        },
                        {
                            "source": "#docm_germline.cwl/interval_list",
                            "id": "#docm_germline.cwl/gatk_haplotypecaller/interval_list"
                        },
                        {
                            "source": "#docm_germline.cwl/reference",
                            "id": "#docm_germline.cwl/gatk_haplotypecaller/reference"
                        }
                    ],
                    "out": [
                        "#docm_germline.cwl/gatk_haplotypecaller/docm_raw_variants"
                    ],
                    "id": "#docm_germline.cwl/gatk_haplotypecaller"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#docm_germline.cwl/bgzip/bgzipped_file",
                            "id": "#docm_germline.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#docm_germline.cwl/index/indexed_vcf"
                    ],
                    "id": "#docm_germline.cwl/index"
                }
            ],
            "id": "#docm_germline.cwl"
        },
        {
            "class": "Workflow",
            "label": "fp_filter workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#fp_filter.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#fp_filter.cwl/min_var_freq"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#fp_filter.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#fp_filter.cwl/sample_name"
                },
                {
                    "type": "string",
                    "id": "#fp_filter.cwl/variant_caller"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#fp_filter.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#fp_filter.cwl/hard_filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#fp_filter.cwl/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#fp_filter.cwl/fp_index/indexed_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#fp_filter.cwl/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#vt_decompose.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/normalize_variants/normalized_vcf",
                            "id": "#fp_filter.cwl/decompose_variants/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/decompose_variants/decomposed_vcf"
                    ],
                    "id": "#fp_filter.cwl/decompose_variants"
                },
                {
                    "run": "#bgzip.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/fp_filter/filtered_vcf",
                            "id": "#fp_filter.cwl/fp_bgzip/file"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/fp_bgzip/bgzipped_file"
                    ],
                    "id": "#fp_filter.cwl/fp_bgzip"
                },
                {
                    "run": "#fp_filter.cwl_2",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/bam",
                            "id": "#fp_filter.cwl/fp_filter/bam"
                        },
                        {
                            "source": "#fp_filter.cwl/min_var_freq",
                            "id": "#fp_filter.cwl/fp_filter/min_var_freq"
                        },
                        {
                            "source": "#fp_filter.cwl/variant_caller",
                            "valueFrom": "$(self)_full",
                            "id": "#fp_filter.cwl/fp_filter/output_vcf_basename"
                        },
                        {
                            "source": "#fp_filter.cwl/reference",
                            "id": "#fp_filter.cwl/fp_filter/reference"
                        },
                        {
                            "source": "#fp_filter.cwl/sample_name",
                            "id": "#fp_filter.cwl/fp_filter/sample_name"
                        },
                        {
                            "source": "#fp_filter.cwl/index/indexed_vcf",
                            "id": "#fp_filter.cwl/fp_filter/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/fp_filter/filtered_vcf"
                    ],
                    "id": "#fp_filter.cwl/fp_filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/fp_bgzip/bgzipped_file",
                            "id": "#fp_filter.cwl/fp_index/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/fp_index/indexed_vcf"
                    ],
                    "id": "#fp_filter.cwl/fp_index"
                },
                {
                    "run": "#select_variants.cwl",
                    "in": [
                        {
                            "default": true,
                            "id": "#fp_filter.cwl/hard_filter/exclude_filtered"
                        },
                        {
                            "source": "#fp_filter.cwl/variant_caller",
                            "valueFrom": "$(self)_filtered",
                            "id": "#fp_filter.cwl/hard_filter/output_vcf_basename"
                        },
                        {
                            "source": "#fp_filter.cwl/reference",
                            "id": "#fp_filter.cwl/hard_filter/reference"
                        },
                        {
                            "source": "#fp_filter.cwl/fp_index/indexed_vcf",
                            "id": "#fp_filter.cwl/hard_filter/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/hard_filter/filtered_vcf"
                    ],
                    "id": "#fp_filter.cwl/hard_filter"
                },
                {
                    "run": "#index_vcf.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/decompose_variants/decomposed_vcf",
                            "id": "#fp_filter.cwl/index/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/index/indexed_vcf"
                    ],
                    "id": "#fp_filter.cwl/index"
                },
                {
                    "run": "#normalize_variants.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/reference",
                            "id": "#fp_filter.cwl/normalize_variants/reference"
                        },
                        {
                            "source": "#fp_filter.cwl/sanitize_vcf/sanitized_vcf",
                            "id": "#fp_filter.cwl/normalize_variants/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/normalize_variants/normalized_vcf"
                    ],
                    "id": "#fp_filter.cwl/normalize_variants"
                },
                {
                    "run": "#vcf_sanitize.cwl",
                    "in": [
                        {
                            "source": "#fp_filter.cwl/vcf",
                            "id": "#fp_filter.cwl/sanitize_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#fp_filter.cwl/sanitize_vcf/sanitized_vcf"
                    ],
                    "id": "#fp_filter.cwl/sanitize_vcf"
                }
            ],
            "id": "#fp_filter.cwl"
        },
        {
            "class": "Workflow",
            "label": "Varscan Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#varscan_germline.cwl/bam"
                },
                {
                    "type": "File",
                    "id": "#varscan_germline.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "id": "#varscan_germline.cwl/max_normal_freq"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "id": "#varscan_germline.cwl/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "id": "#varscan_germline.cwl/min_reads"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "id": "#varscan_germline.cwl/min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "id": "#varscan_germline.cwl/p_value"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#varscan_germline.cwl/reference"
                },
                {
                    "type": "string",
                    "id": "#varscan_germline.cwl/sample_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "id": "#varscan_germline.cwl/strand_filter"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#varscan_germline.cwl/filter/filtered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#varscan_germline.cwl/filtered_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#varscan_germline.cwl/filter/unfiltered_vcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#varscan_germline.cwl/unfiltered_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#bgzip_and_index.cwl",
                    "in": [
                        {
                            "source": "#varscan_germline.cwl/varscan/variants",
                            "id": "#varscan_germline.cwl/bgzip_and_index/vcf"
                        }
                    ],
                    "out": [
                        "#varscan_germline.cwl/bgzip_and_index/indexed_vcf"
                    ],
                    "id": "#varscan_germline.cwl/bgzip_and_index"
                },
                {
                    "run": "#fp_filter.cwl",
                    "in": [
                        {
                            "source": "#varscan_germline.cwl/bam",
                            "id": "#varscan_germline.cwl/filter/bam"
                        },
                        {
                            "source": "#varscan_germline.cwl/min_var_freq",
                            "id": "#varscan_germline.cwl/filter/min_var_freq"
                        },
                        {
                            "source": "#varscan_germline.cwl/reference",
                            "id": "#varscan_germline.cwl/filter/reference"
                        },
                        {
                            "source": "#varscan_germline.cwl/sample_name",
                            "id": "#varscan_germline.cwl/filter/sample_name"
                        },
                        {
                            "valueFrom": "varscan",
                            "id": "#varscan_germline.cwl/filter/variant_caller"
                        },
                        {
                            "source": "#varscan_germline.cwl/bgzip_and_index/indexed_vcf",
                            "id": "#varscan_germline.cwl/filter/vcf"
                        }
                    ],
                    "out": [
                        "#varscan_germline.cwl/filter/unfiltered_vcf",
                        "#varscan_germline.cwl/filter/filtered_vcf"
                    ],
                    "id": "#varscan_germline.cwl/filter"
                },
                {
                    "run": "#intervals_to_bed.cwl",
                    "in": [
                        {
                            "source": "#varscan_germline.cwl/interval_list",
                            "id": "#varscan_germline.cwl/intervals_to_bed/interval_list"
                        }
                    ],
                    "out": [
                        "#varscan_germline.cwl/intervals_to_bed/interval_bed"
                    ],
                    "id": "#varscan_germline.cwl/intervals_to_bed"
                },
                {
                    "run": "#varscan_germline.cwl_2",
                    "in": [
                        {
                            "source": "#varscan_germline.cwl/bam",
                            "id": "#varscan_germline.cwl/varscan/bam"
                        },
                        {
                            "source": "#varscan_germline.cwl/min_coverage",
                            "id": "#varscan_germline.cwl/varscan/min_coverage"
                        },
                        {
                            "source": "#varscan_germline.cwl/min_reads",
                            "id": "#varscan_germline.cwl/varscan/min_reads"
                        },
                        {
                            "source": "#varscan_germline.cwl/min_var_freq",
                            "id": "#varscan_germline.cwl/varscan/min_var_freq"
                        },
                        {
                            "source": "#varscan_germline.cwl/p_value",
                            "id": "#varscan_germline.cwl/varscan/p_value"
                        },
                        {
                            "source": "#varscan_germline.cwl/reference",
                            "id": "#varscan_germline.cwl/varscan/reference"
                        },
                        {
                            "source": "#varscan_germline.cwl/intervals_to_bed/interval_bed",
                            "id": "#varscan_germline.cwl/varscan/roi_bed"
                        },
                        {
                            "source": "#varscan_germline.cwl/sample_name",
                            "id": "#varscan_germline.cwl/varscan/sample_name"
                        },
                        {
                            "source": "#varscan_germline.cwl/strand_filter",
                            "id": "#varscan_germline.cwl/varscan/strand_filter"
                        }
                    ],
                    "out": [
                        "#varscan_germline.cwl/varscan/variants"
                    ],
                    "id": "#varscan_germline.cwl/varscan"
                }
            ],
            "id": "#varscan_germline.cwl"
        },
        {
            "class": "Workflow",
            "label": "Add snv and indel bam-readcount files to a vcf",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        {
                            "type": "enum",
                            "symbols": [
                                "#vcf_readcount_annotator.cwl/data_type/DNA",
                                "#vcf_readcount_annotator.cwl/data_type/RNA"
                            ]
                        }
                    ],
                    "id": "#vcf_readcount_annotator.cwl/data_type"
                },
                {
                    "type": "File",
                    "id": "#vcf_readcount_annotator.cwl/indel_bam_readcount_tsv"
                },
                {
                    "type": "string",
                    "id": "#vcf_readcount_annotator.cwl/sample_name"
                },
                {
                    "type": "File",
                    "id": "#vcf_readcount_annotator.cwl/snv_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#vcf_readcount_annotator.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                    "id": "#vcf_readcount_annotator.cwl/annotated_bam_readcount_vcf"
                }
            ],
            "steps": [
                {
                    "run": "#vcf_readcount_annotator.cwl_2",
                    "in": [
                        {
                            "source": "#vcf_readcount_annotator.cwl/indel_bam_readcount_tsv",
                            "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/bam_readcount_tsv"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/data_type",
                            "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/sample_name",
                            "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "default": "indel",
                            "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/variant_type"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/annotated_bam_readcount_vcf",
                            "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#vcf_readcount_annotator.cwl/add_indel_bam_readcount_to_vcf"
                },
                {
                    "run": "#vcf_readcount_annotator.cwl_2",
                    "in": [
                        {
                            "source": "#vcf_readcount_annotator.cwl/snv_bam_readcount_tsv",
                            "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/bam_readcount_tsv"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/data_type",
                            "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/data_type"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/sample_name",
                            "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/sample_name"
                        },
                        {
                            "default": "snv",
                            "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/variant_type"
                        },
                        {
                            "source": "#vcf_readcount_annotator.cwl/vcf",
                            "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/vcf"
                        }
                    ],
                    "out": [
                        "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf/annotated_bam_readcount_vcf"
                    ],
                    "id": "#vcf_readcount_annotator.cwl/add_snv_bam_readcount_to_vcf"
                }
            ],
            "id": "#vcf_readcount_annotator.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "add VEP annotation to report",
            "baseCommand": [
                "vep-annotation-reporter"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "griffithlab/vatools:3.1.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.prefix).annotated.tsv"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "variants",
                    "id": "#add_vep_fields_to_table.cwl/prefix"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#add_vep_fields_to_table.cwl/tsv"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#add_vep_fields_to_table.cwl/vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "default": [
                        "Consequence",
                        "SYMBOL",
                        "Feature",
                        "HGVSc",
                        "HGVSp"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#add_vep_fields_to_table.cwl/vep_fields"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.prefix).annotated.tsv"
                    },
                    "id": "#add_vep_fields_to_table.cwl/annotated_variants_tsv"
                }
            ],
            "id": "#add_vep_fields_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "run bam-readcount",
            "baseCommand": [
                "/usr/bin/python",
                "bam_readcount_helper.py"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bam_readcount_helper-cwl:1.1.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "bam_readcount_helper.py",
                            "entry": "#!/usr/bin/env python\n\nimport sys\nimport os\nfrom cyvcf2 import VCF\nimport tempfile\nimport csv\nfrom subprocess import Popen, PIPE\n\ndef generate_region_list(hash):\n    fh = tempfile.NamedTemporaryFile('w', delete=False)\n    writer = csv.writer(fh, delimiter='\\t')\n    for chr, positions in hash.items():\n        for pos in sorted(positions.keys()):\n            writer.writerow([chr, pos, pos])\n    fh.close()\n    return fh.name\n\ndef filter_sites_in_hash(region_list, bam_file, ref_fasta, prefixed_sample, output_dir, insertion_centric, map_qual, base_qual):\n    bam_readcount_cmd = ['/usr/bin/bam-readcount', '-f', ref_fasta, '-l', region_list, '-w', '0', '-b', str(base_qual), '-q', str(map_qual)]\n    if insertion_centric:\n        bam_readcount_cmd.append('-i')\n        output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_indel.tsv')\n    else:\n        output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_snv.tsv')\n    bam_readcount_cmd.append(bam_file)\n    execution = Popen(bam_readcount_cmd, stdout=PIPE, stderr=PIPE)\n    stdout, stderr = execution.communicate()\n    if execution.returncode == 0:\n        with open(output_file, 'wb') as output_fh:\n            output_fh.write(stdout)\n    else:\n        sys.exit(stderr)\n\n#initializing these with default values\nmin_base_qual = 20\nmin_mapping_qual = 0\n\nif len(sys.argv) == 7:\n    (script_name, vcf_filename, sample, ref_fasta, bam_file, prefix, output_dir)= sys.argv\nelif len(sys.argv) == 8:\n    (script_name, vcf_filename, sample, ref_fasta, bam_file, prefix, output_dir, min_base_qual)= sys.argv\nelif len(sys.argv) == 9: #elif instead of else for explicit safety\n    (script_name, vcf_filename, sample, ref_fasta, bam_file, prefix, output_dir, min_base_qual, min_mapping_qual)= sys.argv\n\nif prefix == 'NOPREFIX':\n    prefixed_sample = sample\nelse:\n    prefixed_sample = '_'.join([prefix, sample])\n\nvcf_file = VCF(vcf_filename)\nsample_index = vcf_file.samples.index(sample)\n\nrc_for_indel = {}\nrc_for_snp   = {}\nfor variant in vcf_file:\n    ref = variant.REF\n    chr = variant.CHROM\n    start = variant.start\n    end = variant.end\n    pos = variant.POS\n    for var in  variant.ALT:\n        if len(ref) > 1 or len(var) > 1:\n            #it's an indel or mnp\n            if len(ref) == len(var) or (len(ref) > 1 and len(var) > 1):\n                sys.stderr.write(\"Complex variant or MNP will be skipped: %s\\t%s\\t%s\\t%s\\n\" % (chr, pos, ref , var))\n                continue\n            elif len(ref) > len(var):\n                #it's a deletion\n                pos += 1\n                unmodified_ref = ref\n                ref = unmodified_ref[1]\n                var = \"-%s\" % unmodified_ref[1:]\n            else:\n                #it's an insertion\n                var = \"+%s\" % var[1:]\n            if chr not in rc_for_indel:\n                rc_for_indel[chr] = {}\n            if pos not in rc_for_indel[chr]:\n                rc_for_indel[chr][pos] = {}\n            if ref not in rc_for_indel[chr][pos]:\n                rc_for_indel[chr][pos][ref] = {}\n            rc_for_indel[chr][pos][ref] = variant\n        else:\n            #it's a SNP\n            if chr not in rc_for_snp:\n                rc_for_snp[chr] = {}\n            if pos not in rc_for_snp[chr]:\n                rc_for_snp[chr][pos] = {}\n            if ref not in rc_for_snp[chr][pos]:\n                rc_for_snp[chr][pos][ref] = {}\n            rc_for_snp[chr][pos][ref] = variant\n\nif len(rc_for_snp.keys()) > 0:\n    region_file = generate_region_list(rc_for_snp)\n    filter_sites_in_hash(region_file, bam_file, ref_fasta, prefixed_sample, output_dir, False, min_mapping_qual, min_base_qual)\nelse:\n    output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_snv.tsv')\n    open(output_file, 'w').close()\n\nif len(rc_for_indel.keys()) > 0:\n    region_file = generate_region_list(rc_for_indel)\n    filter_sites_in_hash(region_file, bam_file, ref_fasta, prefixed_sample, output_dir, True, min_mapping_qual, min_base_qual)\nelse:\n    output_file = os.path.join(output_dir, prefixed_sample + '_bam_readcount_indel.tsv')\n    open(output_file, 'w').close()\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": -3
                }
            ],
            "stdout": "$(inputs.sample)_bam_readcount.tsv",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -5
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bam_readcount.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20,
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#bam_readcount.cwl/min_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#bam_readcount.cwl/min_mapping_quality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "NOPREFIX",
                    "inputBinding": {
                        "position": -4
                    },
                    "id": "#bam_readcount.cwl/prefix"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": -6
                    },
                    "id": "#bam_readcount.cwl/reference_fasta"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -7
                    },
                    "id": "#bam_readcount.cwl/sample"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -8
                    },
                    "id": "#bam_readcount.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    var name = \"_bam_readcount_indel.tsv\";\n    if (inputs.prefix.equals(\"NOPREFIX\")) {\n        name = inputs.sample + name;\n    }\n    else {\n        name = inputs.prefix + \"_\" + inputs.sample + name;\n    }\n    return name;\n}\n"
                    },
                    "id": "#bam_readcount.cwl/indel_bam_readcount_tsv"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n    var name = \"_bam_readcount_snv.tsv\";\n    if (inputs.prefix.equals(\"NOPREFIX\")) {\n        name = inputs.sample + name;\n    }\n    else {\n        name = inputs.prefix + \"_\" + inputs.sample + name;\n    }\n    return name;\n}\n"
                    },
                    "id": "#bam_readcount.cwl/snv_bam_readcount_tsv"
                }
            ],
            "id": "#bam_readcount.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "bgzip VCF",
            "baseCommand": [
                "/opt/htslib/bin/bgzip"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "$(inputs.file.basename).gz",
            "arguments": [
                "-c"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bgzip.cwl/file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bgzip.cwl/bgzipped_file",
                    "outputBinding": {
                        "glob": "$(inputs.file.basename).gz"
                    }
                }
            ],
            "id": "#bgzip.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "HaplotypeCaller (GATK4)",
            "baseCommand": [
                "/bin/bash",
                "docm_haplotypeCaller.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 9000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.2.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "docm_haplotypeCaller.sh",
                            "entry": "set -o pipefail\nset -o errexit\n\n# Running haplotype caller using the newly created interval list\nif [[ \"$#\" == 5 ]];then # If normal_bam is passed.\n    # explicitly capturing variables\n    reference=$1\n    normal_bam=$2\n    tumor_bam=$3\n    docm_vcf=$4\n    interval_list=$5\n    # Chaning the interval_list to a new docm_interval_list that spans the docm regions by 200bp\n    cat $interval_list | grep '^@' > docm.interval_list # Extracting the header from the interval_list\n    zcat $docm_vcf | grep ^chr | awk '{FS = \"\\t\";OFS = \"\\t\";print $1,$2-100,$2+100,\"+\",$1\"_\"$2-100\"_\"$2+100}' >> docm.interval_list # Extracting the docm regions with a 100bp flanking region on both directions\n    /gatk/gatk HaplotypeCaller --java-options \"-Xmx8g\" -R $reference -I $normal_bam -I $tumor_bam --alleles $docm_vcf -L docm.interval_list --genotyping-mode GENOTYPE_GIVEN_ALLELES -O docm_raw_variants.vcf\nelse # If normal_bam is not passed\n    reference=$1\n    tumor_bam=$2\n    docm_vcf=$3\n    interval_list=$4\n    # Chaning the interval_list to a new docm_interval_list that spans the docm regions by 200bp\n    cat $interval_list | grep '^@' > docm.interval_list # Extracting the header from the interval_list\n    zcat $docm_vcf | grep ^chr | awk '{FS = \"\\t\";OFS = \"\\t\";print $1,$2-100,$2+100,\"+\",$1\"_\"$2-100\"_\"$2+100}' >> docm.interval_list # Extracting the docm regions with a 100bp flanking region on both directions\n    /gatk/gatk HaplotypeCaller --java-options \"-Xmx8g\" -R $reference -I $tumor_bam --alleles $docm_vcf -L docm.interval_list --genotyping-mode GENOTYPE_GIVEN_ALLELES -O docm_raw_variants.vcf\nfi\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#docm_gatk_haplotype_caller.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#docm_gatk_haplotype_caller.cwl/docm_vcf"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#docm_gatk_haplotype_caller.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#docm_gatk_haplotype_caller.cwl/normal_bam"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#docm_gatk_haplotype_caller.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "docm_raw_variants.vcf"
                    },
                    "id": "#docm_gatk_haplotype_caller.cwl/docm_raw_variants"
                }
            ],
            "id": "#docm_gatk_haplotype_caller.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Coding Variant filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/vcf_check.pl"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/vep_helper-cwl:1.1.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.vcf.path)"
                },
                {
                    "valueFrom": "$(runtime.outdir)/annotated.coding_variant_filtered.vcf"
                },
                "/usr/bin/perl",
                "/opt/vep/src/ensembl-vep/filter_vep",
                "--format",
                "vcf",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.coding_variant_filtered.vcf"
                },
                "--ontology",
                "--filter",
                "Consequence is coding_sequence_variant"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#filter_vcf_coding_variant.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.coding_variant_filtered.vcf"
                    },
                    "id": "#filter_vcf_coding_variant.cwl/filtered_vcf"
                }
            ],
            "id": "#filter_vcf_coding_variant.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Custom allele frequency filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/vcf_check.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/vep_helper-cwl:1.1.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.vcf.path)"
                },
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                },
                "/usr/bin/perl",
                "/opt/vep/src/ensembl-vep/filter_vep",
                "--format",
                "vcf",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#filter_vcf_custom_allele_freq.cwl/field_name"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "valueFrom": "${\n    return [\n        \"--filter\",\n        [\n            inputs.field_name, \"<\", inputs.maximum_population_allele_frequency,\n            \"or not\", inputs.field_name\n        ].join(\" \")\n    ]\n}\n",
                        "position": 2
                    },
                    "id": "#filter_vcf_custom_allele_freq.cwl/maximum_population_allele_frequency"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#filter_vcf_custom_allele_freq.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.af_filtered.vcf"
                    },
                    "id": "#filter_vcf_custom_allele_freq.cwl/filtered_vcf"
                }
            ],
            "id": "#filter_vcf_custom_allele_freq.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "False Positive filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/fpfilter.pl"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/fp_filter-cwl:1.0.1"
                }
            ],
            "arguments": [
                "--bam-readcount",
                "/usr/bin/bam-readcount",
                "--samtools",
                "/opt/samtools/bin/samtools",
                "--output",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam-file",
                        "position": 2
                    },
                    "id": "#fp_filter.cwl_2/bam"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.05,
                    "inputBinding": {
                        "prefix": "--min-var-freq",
                        "position": 5
                    },
                    "id": "#fp_filter.cwl_2/min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "fpfilter",
                    "id": "#fp_filter.cwl_2/output_vcf_basename"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "--reference",
                        "position": 1
                    },
                    "id": "#fp_filter.cwl_2/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "TUMOR",
                    "inputBinding": {
                        "prefix": "--sample",
                        "position": 4
                    },
                    "id": "#fp_filter.cwl_2/sample_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf-file",
                        "position": 3
                    },
                    "id": "#fp_filter.cwl_2/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf"
                    },
                    "id": "#fp_filter.cwl_2/filtered_vcf"
                }
            ],
            "id": "#fp_filter.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "label": "CombineVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "CombineVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 9000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-genotypeMergeOptions",
                "PRIORITIZE",
                "--rod_priority_list",
                "varscan,docm",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/combined.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:docm",
                        "position": 6
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_combine_variants.cwl/docm_vcf"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#germline_combine_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant:varscan",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#germline_combine_variants.cwl/varscan_vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "combined.vcf.gz"
                    },
                    "id": "#germline_combine_variants.cwl/combined_vcf"
                }
            ],
            "id": "#germline_combine_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "vcf index",
            "arguments": [
                "cp",
                "$(inputs.vcf.path)",
                "$(runtime.outdir)/$(inputs.vcf.basename)",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "/usr/bin/tabix",
                "-p",
                "vcf"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(self.basename)",
                        "position": 1
                    },
                    "id": "#index_vcf.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.vcf.basename)"
                    },
                    "id": "#index_vcf.cwl/indexed_vcf"
                }
            ],
            "id": "#index_vcf.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "/usr/bin/perl",
                "intervals_to_bed.pl"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:bionic"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "intervals_to_bed.pl",
                            "entry": "use feature qw(say);\n\nfor my $line (<>) {\n    chomp $line;\n\n    next if substr($line,0,1) eq '@'; #skip header lines\n\n    my ($chrom, $start, $stop) = split(/\\t/, $line);\n    say(join(\"\\t\", $chrom, $start-1, $stop));\n}\n"
                        }
                    ]
                }
            ],
            "stdout": "interval_list.bed",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#intervals_to_bed.cwl/interval_list"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#intervals_to_bed.cwl/interval_bed",
                    "outputBinding": {
                        "glob": "interval_list.bed"
                    }
                }
            ],
            "id": "#intervals_to_bed.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Normalize variants",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx8g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "LeftAlignAndTrimVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 9000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/normalized.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#normalize_variants.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#normalize_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "normalized.vcf.gz"
                    },
                    "id": "#normalize_variants.cwl/normalized_vcf"
                }
            ],
            "id": "#normalize_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "SelectVariants"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_vcf_basename).vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--excludeFiltered",
                        "position": 4
                    },
                    "id": "#select_variants.cwl/exclude_filtered"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-L",
                        "position": 3
                    },
                    "id": "#select_variants.cwl/interval_list"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "select_variants",
                    "id": "#select_variants.cwl/output_vcf_basename"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#select_variants.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--sample_name",
                        "position": 5
                    },
                    "doc": "include genotypes from this sample",
                    "id": "#select_variants.cwl/samples_to_include"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#select_variants.cwl/select_type/INDEL",
                                "#select_variants.cwl/select_type/SNP",
                                "#select_variants.cwl/select_type/MIXED",
                                "#select_variants.cwl/select_type/MNP",
                                "#select_variants.cwl/select_type/SYMBOLIC",
                                "#select_variants.cwl/select_type/NO_VARIATION"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-selectType",
                        "position": 6
                    },
                    "doc": "select only a certain type of variants",
                    "id": "#select_variants.cwl/select_type"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#select_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.output_vcf_basename).vcf.gz"
                    },
                    "id": "#select_variants.cwl/filtered_vcf"
                }
            ],
            "id": "#select_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "docm filter",
            "arguments": [
                "/usr/bin/perl",
                "/usr/bin/single_sample_docm_filter.pl",
                "$(inputs.docm_out.path)",
                "$(runtime.outdir)"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/perl_helper-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#single_sample_docm_filter.cwl/docm_out"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "docm_filter_out.vcf"
                    },
                    "id": "#single_sample_docm_filter.cwl/docm_filter_out"
                }
            ],
            "id": "#single_sample_docm_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "SelectVariants (GATK 3.6)",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/GenomeAnalysisTK.jar",
                "-T",
                "VariantsToTable"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/gatk-cwl:3.6.0"
                }
            ],
            "arguments": [
                "--allowMissingData",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/variants.tsv"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-F"
                        }
                    },
                    "default": [
                        "CHROM",
                        "POS",
                        "ID",
                        "REF",
                        "ALT",
                        "set"
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#variants_to_table.cwl/fields"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-GF"
                        }
                    },
                    "default": [
                        "GT",
                        "AD",
                        "DP",
                        "AF"
                    ],
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#variants_to_table.cwl/genotype_fields"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#variants_to_table.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--variant",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#variants_to_table.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "variants.tsv"
                    },
                    "id": "#variants_to_table.cwl/variants_tsv"
                }
            ],
            "id": "#variants_to_table.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "varscan v2.4.2 germline",
            "baseCommand": "/usr/bin/varscan_germline_helper.sh",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 12000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/varscan_helper-cwl:1.0.0"
                }
            ],
            "arguments": [
                {
                    "position": 9,
                    "valueFrom": "$(runtime.outdir)/output.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#varscan_germline.cwl_2/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 8,
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#varscan_germline.cwl_2/min_coverage"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "inputBinding": {
                        "position": 6
                    },
                    "id": "#varscan_germline.cwl_2/min_reads"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.1,
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#varscan_germline.cwl_2/min_var_freq"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.99,
                    "inputBinding": {
                        "position": 7
                    },
                    "id": "#varscan_germline.cwl_2/p_value"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#varscan_germline.cwl_2/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 10
                    },
                    "id": "#varscan_germline.cwl_2/roi_bed"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#varscan_germline.cwl_2/sample_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#varscan_germline.cwl_2/strand_filter"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.vcf"
                    },
                    "id": "#varscan_germline.cwl_2/variants"
                }
            ],
            "id": "#varscan_germline.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "label": "add bam_readcount info to vcf",
            "baseCommand": [
                "vcf-readcount-annotator"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "griffithlab/vatools:3.1.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.bam_readcount.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/bam_readcount_tsv"
                },
                {
                    "type": [
                        {
                            "type": "enum",
                            "symbols": [
                                "#vcf_readcount_annotator.cwl_2/data_type/DNA",
                                "#vcf_readcount_annotator.cwl_2/data_type/RNA"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/data_type"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/sample_name"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#vcf_readcount_annotator.cwl_2/variant_type/snv",
                                "#vcf_readcount_annotator.cwl_2/variant_type/indel",
                                "#vcf_readcount_annotator.cwl_2/variant_type/all"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/variant_type"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.bam_readcount.vcf.gz"
                    },
                    "id": "#vcf_readcount_annotator.cwl_2/annotated_bam_readcount_vcf"
                }
            ],
            "id": "#vcf_readcount_annotator.cwl_2"
        },
        {
            "class": "CommandLineTool",
            "label": "Sanitize a VCF",
            "baseCommand": [
                "/bin/bash",
                "sanitize.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000,
                    "coresMin": 1
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "sanitize.sh",
                            "entry": "set -eou pipefail\n\n# 1) removes lines containing non ACTGN bases, as they conflict with the VCF spec\n# and cause GATK to choke\n# 2) removes mutect-specific format tags containing underscores, which are likewise\n# illegal in the vcf spec\nbase=`basename $1`\noutbase=`echo $base | perl -pe 's/.vcf(.gz)?$//g'`\necho \"$1   $base    $outbase\"\nif [[ \"$1\" =~ \".gz\" ]];then\n    #gzipped input\n    gunzip -c \"$1\" | perl -a -F'\\t' -ne 'print $_ if $_ =~ /^#/ || $F[3] !~ /[^ACTGNactgn]/' | sed -e \"s/ALT_F1R2/ALTF1R2/g;s/ALT_F2R1/ALTF2R1/g;s/REF_F1R2/REFF1R2/g;s/REF_F2R1/REFF2R1/g\" >$outbase.sanitized.vcf\nelse\n    #non-gzipped input\n    cat \"$1\" | perl -a -F'\\t' -ne 'print $_ if $_ =~ /^#/ || $F[3] !~ /[^ACTGNactgn]/' | sed -e \"s/ALT_F1R2/ALTF1R2/g;s/ALT_F2R1/ALTF2R1/g;s/REF_F1R2/REFF1R2/g;s/REF_F2R1/REFF2R1/g\" >$outbase.sanitized.vcf\nfi\n/opt/htslib/bin/bgzip $outbase.sanitized.vcf\n/usr/bin/tabix -p vcf $outbase.sanitized.vcf.gz\n"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#vcf_sanitize.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "outputBinding": {
                        "glob": "${\n  if(inputs.vcf.nameext.equals(\".gz\")){\n    return inputs.vcf.nameroot.replace(/.vcf$/, \"\") + \".sanitized.vcf.gz\";\n  }\n  return inputs.vcf.nameroot + \".sanitized.vcf.gz\";\n}\n"
                    },
                    "id": "#vcf_sanitize.cwl/sanitized_vcf"
                }
            ],
            "id": "#vcf_sanitize.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Ensembl Variant Effect Predictor",
            "baseCommand": [
                "/usr/bin/perl",
                "-I",
                "/opt/lib/perl/VEP/Plugins",
                "/usr/bin/variant_effect_predictor.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#vep_custom_annotation.yml/vep_custom_annotation"
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 4,
                    "ramMin": 64000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/vep_helper-cwl:1.1.0"
                }
            ],
            "arguments": [
                "--format",
                "vcf",
                "--vcf",
                "--fork",
                "4",
                "--term",
                "SO",
                "--transcript_version",
                "--offline",
                "--cache",
                "--symbol",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.vcf.nameroot)_annotated.vcf"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "string",
                        "Directory"
                    ],
                    "inputBinding": {
                        "prefix": "--dir",
                        "position": 4
                    },
                    "id": "#vep.cwl/cache_dir"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--coding_only",
                        "position": 3
                    },
                    "default": false,
                    "id": "#vep.cwl/coding_only"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "#vep_custom_annotation.yml/vep_custom_annotation",
                            "label": "custom type, check types directory for input format",
                            "inputBinding": {
                                "valueFrom": "${\n    return [self.annotation.check_existing ? '--check_existing' : '',\n      '--custom',\n      [self.annotation.file.path,\n      self.annotation.name,\n      self.annotation.data_format,\n      self.method,\n      self.force_report_coordinates ? 1 : 0,\n      self.annotation.vcf_fields ? self.annotation.vcf_fields : ''\n      ].filter(String).join(',')\n    ].filter(String)\n}\n",
                                "position": 6
                            }
                        }
                    ],
                    "id": "#vep.cwl/custom_annotations"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--assembly",
                        "position": 10
                    },
                    "doc": "genome assembly to use in vep. Examples: 'GRCh38' or 'GRCm38'",
                    "id": "#vep.cwl/ensembl_assembly"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--species",
                        "position": 12
                    },
                    "doc": "ensembl species - Must be present in the cache directory. Examples: 'homo_sapiens' or 'mus_musculus'",
                    "id": "#vep.cwl/ensembl_species"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--cache_version",
                        "position": 11
                    },
                    "doc": "ensembl version - Must be present in the cache directory. Example: '95'",
                    "id": "#vep.cwl/ensembl_version"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": true,
                    "inputBinding": {
                        "prefix": "--everything",
                        "position": 9
                    },
                    "id": "#vep.cwl/everything"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#vep.cwl/pick/pick",
                                "#vep.cwl/pick/flag_pick",
                                "#vep.cwl/pick/pick_allele",
                                "#vep.cwl/pick/per_gene",
                                "#vep.cwl/pick/pick_allele_gene",
                                "#vep.cwl/pick/flag_pick_allele",
                                "#vep.cwl/pick/flag_pick_allele_gene"
                            ]
                        }
                    ],
                    "default": "flag_pick",
                    "inputBinding": {
                        "prefix": "--",
                        "separate": false,
                        "position": 7
                    },
                    "id": "#vep.cwl/pick"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "--plugin"
                        }
                    },
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#vep.cwl/plugins"
                },
                {
                    "type": [
                        "null",
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "--fasta",
                        "position": 7
                    },
                    "id": "#vep.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--synonyms",
                        "position": 2
                    },
                    "id": "#vep.cwl/synonyms_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#vep.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.vcf.nameroot)_annotated.vcf"
                    },
                    "id": "#vep.cwl/annotated_vcf"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.vcf.nameroot)_annotated.vcf_summary.html"
                    },
                    "id": "#vep.cwl/vep_summary"
                }
            ],
            "id": "#vep.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "run vt decompose",
            "baseCommand": [
                "vt",
                "decompose"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/biocontainers/vt:0.57721--hf74b74d_1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "-s",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/decomposed.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#vt_decompose.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "decomposed.vcf.gz"
                    },
                    "id": "#vt_decompose.cwl/decomposed_vcf"
                }
            ],
            "id": "#vt_decompose.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
